/*
CGI to handle Carrier on / off & Set temperature 
*/

#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include <espressif/esp_common.h>

#include <FreeRTOS.h>
#include <task.h>

#include "cgi-clim.h"
#include "io.h"

#include "midea-ir.h"
extern MideaIR ir;

static int currTemperature = 0;

int ICACHE_FLASH_ATTR cgiClim(HttpdConnData *connData)
{
    int len;          //length of user name
    char temp[128];   //Temporary buffer for temperature
    char output[256]; //Temporary buffer for HTML output

    //If the browser unexpectedly closes the connection, the CGI will be called
    //with connData->conn=NULL. We can use this to clean up any data. It's not really
    //used in this simple CGI function.
    if (connData->conn == NULL)
    {
        //Connection aborted. Clean up.
        return HTTPD_CGI_DONE;
    }

    if (connData->requestType != HTTPD_METHOD_GET)
    {
        //Sorry, we only accept GET requests.
        httpdStartResponse(connData, 406); //http error code 'unacceptable'
        httpdEndHeaders(connData);
        return HTTPD_CGI_DONE;
    }

    //Look for the 'name' GET value. If found, urldecode it and return it into the 'name' var.
    len = httpdFindArg(connData->getArgs, "temp", temp, sizeof(temp));
    if (len == -1)
    {
        //If the result of httpdFindArg is -1, the variable isn't found in the data. Set temp to zero (cutoff heater)
        strcpy(temp, "0");
    }
    else
    {
        //If len isn't -1, the variable is found and is copied to the 'name' variable
    }

    // integer temperature (0,18,18,20,21..)
    currTemperature = atoi(temp);
    
    //switch on led
    ioLed(0);

    if (currTemperature==0) {
        ir.enabled = false;
        printf("Arret de la clim\n");
        midea_ir_send(&ir); 
    }
    else {
        // limit from 15 .. 22 degrees
        if (currTemperature > 22) currTemperature=22;
        if (currTemperature<15) currTemperature=15;
        // set datablock and IR send.
        ir.enabled = true;
        ir.mode = MODE_HEAT;
        ir.temperature = currTemperature;
        ir.fan_level = 2;
        printf("Alumage en chauffage, fanlevel=2, temperature: %d\n",currTemperature);    
        midea_ir_send(&ir);
            }

    httpdRedirect(connData, "temp.tpl");

    // delay 100ms to see the led blink
    vTaskDelay(100 / portTICK_PERIOD_MS);
    ioLed(1);     

    return HTTPD_CGI_DONE;
}

//Template code for the led page.
int ICACHE_FLASH_ATTR tplClim(HttpdConnData *connData, char *token, void **arg)
{
    char buff[128];
    if (token == NULL)
        return HTTPD_CGI_DONE;

    if (strcmp(token, "currenttemp") == 0)
    {
        if (currTemperature == 0)
        {
            strcpy(buff, "Chauffage Arr&ecirc;t&eacute; ");
        }
        else
        {
            sprintf(buff, "%d &deg;C", currTemperature);
        }
    }
    httpdSend(connData, buff, -1);
    return HTTPD_CGI_DONE;
}